pub fn parse_device_bound(
raw: &[u8],
now: DateTime<Utc>,
) -> Result<Envelope<DeviceBound>, ProtocolError>Expand description
Parse a frame the daemon received from the platform.
pub fn parse_device_bound(
raw: &[u8],
now: DateTime<Utc>,
) -> Result<Envelope<DeviceBound>, ProtocolError>Parse a frame the daemon received from the platform.